use std::env;

fn caesar_cipher(text: &mut String, rotation: u32, encrypt: bool) {
    let mut message = String::new();
    let shift = if encrypt { rotation } else { 26 - rotation };

    for char in text.chars() {
        if char.is_alphabetic() {
            let base = if char.is_lowercase() {
                'a' as u32
            } else {
                'A' as u32
            };
            let shifted = (char as u32 - base + shift) % 26;
            let result = (shifted + base) as u8 as char;
            message.push(result);
        } else {
            message.push(char);
        }
    }

    *text = message;
}

fn main() {
    let args: Vec<String> = env::args().collect();

    if args.len() != 4 {
        println!("Usage: caesar_cipher <encrypt/decrypt> <rotation> <message>");
        return;
    }

    let action = &args[1];
    let rotation = args[2].parse::<u32>();

    if action == "encrypt" || action == "decrypt" {
        match rotation {
            Ok(r) => {
                let mut message = args[3].clone();
                let encrypt = action == "encrypt";
                caesar_cipher(&mut message, r, encrypt);
                println!("Result: {}", message);
            }
            Err(_) => println!("Rotation must be a positive integer."),
        }
    } else {
        println!("Action must be 'encrypt' or 'decrypt'.");
    }
}
